Welcome to rpmdeplint's documentation!
======================================

Rpmdeplint is a tool to find errors in RPM packages in the context of their
dependency graph.


.. toctree::
   :maxdepth: 2

   rpmdeplint
   api
   CHANGES
